import type { NormalizedExecutorContext } from '../internal/context.js';
import type { AutorunCommandExecutorOnlyOptions, AutorunCommandExecutorOptions } from './schema.js';
export declare function parseAutorunExecutorOnlyOptions(options: Partial<AutorunCommandExecutorOnlyOptions>): AutorunCommandExecutorOnlyOptions;
export declare function parseAutorunExecutorOptions(options: Partial<AutorunCommandExecutorOptions>, normalizedContext: NormalizedExecutorContext): AutorunCommandExecutorOptions;
/**
 * Deeply merges executor options.
 *
 * @param targetOptions - The original options from the target configuration.
 * @param cliOptions - The options from Nx, combining target options and CLI arguments.
 * @returns A new object with deeply merged properties.
 *
 * Nx performs a shallow merge by default, where command-line arguments can override entire objects
 * (e.g., `--persist.filename` replaces the entire `persist` object).
 * This function ensures that nested properties are deeply merged,
 * preserving the original target options where CLI arguments are not provided.
 */
export declare function mergeExecutorOptions(targetOptions: Partial<AutorunCommandExecutorOptions>, cliOptions: Partial<AutorunCommandExecutorOptions>): AutorunCommandExecutorOptions;
