"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAutorunExecutorOnlyOptions = parseAutorunExecutorOnlyOptions;
exports.parseAutorunExecutorOptions = parseAutorunExecutorOptions;
exports.mergeExecutorOptions = mergeExecutorOptions;
const config_js_1 = require("../internal/config.js");
function parseAutorunExecutorOnlyOptions(options) {
    const { projectPrefix, dryRun, onlyPlugins } = options;
    return {
        ...(projectPrefix && { projectPrefix }),
        ...(dryRun != null && { dryRun }),
        ...(onlyPlugins && { onlyPlugins }),
    };
}
function parseAutorunExecutorOptions(options, normalizedContext) {
    const { projectPrefix, persist, upload, command } = options;
    const needsUploadParams = command === 'upload' || command === 'autorun' || command === undefined;
    return {
        ...parseAutorunExecutorOnlyOptions(options),
        ...(0, config_js_1.globalConfig)(options, normalizedContext),
        persist: (0, config_js_1.persistConfig)({ projectPrefix, ...persist }, normalizedContext),
        // @TODO This is a hack to avoid validation errors of upload config for commands that dont need it.
        // Fix: use utils and execute the core logic directly
        // Blocked by Nx plugins can't compile to es6
        upload: needsUploadParams
            ? (0, config_js_1.uploadConfig)({ projectPrefix, ...upload }, normalizedContext)
            : undefined,
    };
}
/**
 * Deeply merges executor options.
 *
 * @param targetOptions - The original options from the target configuration.
 * @param cliOptions - The options from Nx, combining target options and CLI arguments.
 * @returns A new object with deeply merged properties.
 *
 * Nx performs a shallow merge by default, where command-line arguments can override entire objects
 * (e.g., `--persist.filename` replaces the entire `persist` object).
 * This function ensures that nested properties are deeply merged,
 * preserving the original target options where CLI arguments are not provided.
 */
function mergeExecutorOptions(targetOptions, cliOptions) {
    return {
        ...targetOptions,
        ...cliOptions,
        ...(targetOptions?.persist || cliOptions?.persist
            ? {
                persist: {
                    ...targetOptions?.persist,
                    ...cliOptions?.persist,
                },
            }
            : {}),
        ...(targetOptions?.upload || cliOptions?.upload
            ? {
                upload: {
                    ...targetOptions?.upload,
                    ...cliOptions?.upload,
                },
            }
            : {}),
    };
}
//# sourceMappingURL=utils.js.map